summaryrefslogtreecommitdiff
path: root/include/kernel/con.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/kernel/con.h')
-rw-r--r--include/kernel/con.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/include/kernel/con.h b/include/kernel/con.h
index 4e564ed..bdfefa0 100644
--- a/include/kernel/con.h
+++ b/include/kernel/con.h
@@ -1,7 +1,7 @@
/*
* con.h
*
* Basic VGA text console
*/
#ifndef _CON_H
@@ -9,6 +9,7 @@
void con_init(void);
-void con_print(char*);
+int puts(char *s);
+int printf(char*, ...);
#endif
@@ -1,7 +1,7 @@
* con.h
*
- * Basic VGA text console
+ * Basic VGA text console. Implements printf() and puts().
*/
#ifndef _CON_H